Learn R Programming

curtailment (version 0.2.6)

find2stageThetaF: Find conditional power for futility

Description

Finds maximum conditional power at which trial will stop for futility

Usage

find2stageThetaF(r, r1, n2, p)

Value

The maximum conditional power at which the trial will stop for futility. This is the CP when there are r1 responses out of n1 participants.

Arguments

r

Number of responses to be exceeded for trial success

r1

Number of responses to be exceeded to continue to second stage

n2

Sample size of second stage

p

Response rate under alternative hypothesis H1

Examples

Run this code
find2stageThetaF(r=20, r1=8, n2=13, p=0.92)

Run the code above in your browser using DataLab