Learn R Programming

curtailment (version 0.2.6)

findNSCdesigns: findNSCdesigns

Description

This function finds admissible design realisations for single-arm binary outcome trials, using non-stochastic curtailment. The output is a data frame of admissible design realisations.

Usage

findNSCdesigns(nmin, nmax, p0, p1, alpha, power, progressBar = FALSE)

Value

Output is a list of two dataframes. The first, $input, is a one-row data frame that contains important arguments used in the call. The second, $all.des,contains the operating characteristics of all admissible designs found.

Arguments

nmin

Minimum permitted sample size.

nmax

Maximum permitted sample size.

p0

Probability for which to control the type-I error-rate

p1

Probability for which to control the power

alpha

Significance level

power

Required power (1-beta).

progressBar

Logical. If TRUE, shows progress bar. Defaults to FALSE.

Examples

Run this code
findNSCdesigns(nmin=20, nmax=21, p0=0.1, p1=0.4, alpha=0.1, power=0.8)

Run the code above in your browser using DataLab