powered by
Finds maximum conditional power at which trial will stop for futility
find2stageThetaF(r, r1, n2, p)
The maximum conditional power at which the trial will stop for futility. This is the CP when there are r1 responses out of n1 participants.
Number of responses to be exceeded for trial success
Number of responses to be exceeded to continue to second stage
Sample size of second stage
Response rate under alternative hypothesis H1
find2stageThetaF(r=20, r1=8, n2=13, p=0.92)
Run the code above in your browser using DataLab